@@ -14,7 +14,7 @@ Image::ANSI::Palette - A base class palettes
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 METHODS
 
@@ -31,8 +31,10 @@ sub new {
 
 	bless $self, $class;
 
+	$self->clear;
+
 	if( $palette ) {
-		for( 0..@$palette ) {
+		for( 0..@$palette - 1 ) {
 			$self->set( $_, $palette->[ $_ ] );
 		}
 	}
@@ -78,6 +80,20 @@ sub clear {
 	$self->{ data } = [];
 }
 
+=head2 colors( )
+
+General accessor to the palette of colors
+
+=cut
+
+sub colors {
+	my $self = shift;
+
+        $self->{ data } = $_[ 0 ] if @_;
+
+	return $self->{ data };
+}
+
 =head1 AUTHOR
 
 =over 4 
